@@ -1,11 +1,12 @@
 """
 Replace imports from django.utils.encoding:
-https://docs.djangoproject.com/en/3.0/releases/3.0/#django-utils-encoding-force-text-and-smart-text  # noqa: B950
+https://docs.djangoproject.com/en/3.0/releases/3.0/#django-utils-encoding-force-text-and-smart-text  # noqa: E501
 """
+from __future__ import annotations
+
 import ast
-import re
 from functools import partial
-from typing import Iterable, List, Tuple
+from typing import Iterable
 
 from tokenize_rt import Offset, Token
 
@@ -21,29 +22,23 @@ fixer = Fixer(
 OLD_NAME = "PASSWORD_RESET_TIMEOUT_DAYS"
 NEW_NAME = "PASSWORD_RESET_TIMEOUT"
 
-settings_re = re.compile(r"\bsettings\b")
-
-
-def looks_like_settings_file(filename: str) -> bool:
-    return settings_re.search(filename) is not None
-
 
 @fixer.register(ast.Assign)
 def visit_Assign(
     state: State,
     node: ast.Assign,
     parent: ast.AST,
-) -> Iterable[Tuple[Offset, TokenFunc]]:
+) -> Iterable[tuple[Offset, TokenFunc]]:
     if (
         len(node.targets) == 1
         and isinstance(node.targets[0], ast.Name)
         and node.targets[0].id == OLD_NAME
-        and looks_like_settings_file(state.filename)
+        and state.looks_like_settings_file()
     ):
         yield ast_start_offset(node), partial(rewrite_setting, node=node)
 
 
-def rewrite_setting(tokens: List[Token], i: int, *, node: ast.Assign) -> None:
+def rewrite_setting(tokens: list[Token], i: int, *, node: ast.Assign) -> None:
     tokens[i] = tokens[i]._replace(name=CODE, src=NEW_NAME)
     j = find(tokens, i, name=OP, src="=")
     tokens.insert(j + 1, Token(name=CODE, src=" 60 * 60 * 24 *"))
