@@ -3,6 +3,7 @@ from __future__ import annotations
 import argparse
 import sys
 import tokenize
+from importlib import metadata
 from typing import Sequence, Tuple, cast
 
 from tokenize_rt import (
@@ -38,6 +39,11 @@ def main(argv: Sequence[str] | None = None) -> int:
             "4.0",
         ],
     )
+    parser.add_argument(
+        "--version",
+        action="version",
+        version=f'%(prog)s {metadata.version("django-upgrade")}',
+    )
     args = parser.parse_args(argv)
 
     target_version: tuple[int, int] = cast(
